.. _vergiftiging:

VERGIFTIGING
############

“Test toont dat men aan het vergiftigen is. De bijwerkingen zijn vergiftigingssymptomen.”

Table 9. Common Adverse Reactions (≥5%) in the 6-Week, Randomized, Chlorpromazine-controlled Trial in Treatment-Resistant Schizophrenia:

| Sedation 21
| Tachycardia 17
| Constipation 16
| Dizziness 14
| Hypotension 13
| Fever (hyperthermia) 13
| Hypersalivation 13
| Hypertension 12
| Headache 10
| Nausea/vomiting 10
| Dry mouth 5
